#
# Makefile for NFF stuff using Zortech C++.
#
# The typical command line to build an executable is:
#
#	make -f ztc.mak balls.exe
#
# If you have a different compiler, just note the meaning of the
# various flags and set appropriately.
#

#
# Use these definitions with Zortech C
#
CC	=ztc
#
# Memory model switches for real mode and protected mode
#
#  l    Flag for real mode large model
#  z    Flag for 286 protected mode
#
MDL	=l
#MDL	=z
#
# Link options
#
# /M     Generates a map file
# /F     Farcall (register based parameter passing)
# /PACKC Packs the execuatble code
# /CO    Generates a CodeView debugger compatible executable
#
LINK	=blink /M /F /PACKC
#LINK	=blink /M /CO
#
# Compiler switches
#
# -A     Enforces ANSI C
# -r     Enforces function prototyping
# -2     Generates 80286 specific code
# -f     Generates inline 80x87 code
# -s     Generates stack checking code
# -g     Generates debugging code (not useful in the protected model)
# -DZTC  Tells Polyray that the compiler being used is Zortech
# -o     Turns on optimization
# -br    Uses protected mode versions of the compiler components
#        (A couple of the files need this: height.c, polynom.c, ytab.c)
#
CFLAGS	=-m$(MDL) -2 -f -A -r -DZTC
OPTFLG	=-o
PROTCC	=-br
#
# Link response files for real mode and protected mode
#
#LINKFILE = ztc.lnk
LINKFILE = ztcp.lnk

# Rule to compile c progs into obj's
.c.obj:
	$(CC) $(CFLAGS) -c $<

lib.obj: lib.c lib.h

balls.exe: lib.obj balls.obj
   $(CC) $(CFLAGS) -oballs balls.obj lib.obj

coil.exe: lib.obj coil.obj
   $(CC) $(CFLAGS) -ocoil coil.obj lib.obj

gears.exe: lib.obj gears.obj
   $(CC) $(CFLAGS) -ogears gears.obj lib.obj

hilbert.exe: lib.obj hilbert.obj
   $(CC) $(CFLAGS) -ohilbert hilbert.obj lib.obj

mountain.exe: lib.obj mountain.obj
   $(CC) $(CFLAGS) -omountain mountain.obj lib.obj

rings.exe: lib.obj rings.obj
   $(CC) $(CFLAGS) -orings rings.obj lib.obj

sphcoil.exe: lib.obj sphcoil.obj
   $(CC) $(CFLAGS) -osphcoil sphcoil.obj lib.obj

tetra.exe: lib.obj tetra.obj
   $(CC) $(CFLAGS) -otetra tetra.obj lib.obj

tree.exe: lib.obj tree.obj
   $(CC) $(CFLAGS) -otree tree.obj lib.obj

twistwir.exe: lib.obj twistwir.obj
   $(CC) $(CFLAGS) -otwistwir twistwir.obj lib.obj

